@@ -83,7 +83,9 @@
 #' @export
 k_factor_normal <- function(n, p = 0.90, conf = 0.95) {
   z <- qnorm(p)
-  t <- qt(conf, df = n - 1, ncp = z * sqrt(n))
+  suppressWarnings(
+    t <- qt(conf, df = n - 1, ncp = z * sqrt(n))
+  )
   return(t / sqrt(n))
 }
 
@@ -208,9 +210,17 @@ k_factor_normal <- function(n, p = 0.90, conf = 0.95) {
 #' "optimum-order" in this package.
 #' The results of `basis_hk_ext` have been
 #' verified against example results from the program STAT-17. Agreement is
-#' typically well within 0.2\%, however, for a few sample sizes, the
-#' agreement can be as poor as 1\% with the result of this function
-#' being more conservative than STAT-17.
+#' typically well within 0.2%.
+#'
+#' Note that the implementation of `hk_ext_z_j_opt` changed after `cmstatr`
+#' version 0.8.0. This function is used internally by `basis_hk_ext`
+#' when `method = "optimum-order"`. This implementation change may mean
+#' that basis values computed using this method may change slightly
+#' after version 0.8.0. However, both implementations seem to be equally
+#' valid. See the included vignette
+#' for a discussion of the differences between the implementation before
+#' and after version 0.8.0, as well as the factors given in CMH-17-1G.
+#' To access this vignette, run: `vignette("hk_ext", package = "cmstatr")`
 #'
 #' `basis_hk_ext` also performs
 #' a diagnostic test for outliers (using
@@ -1209,19 +1219,24 @@ hk_ext_z <- function(n, i, j, p, conf) {
   z
 }
 
+
 #' @rdname hk_ext
 #' @export
 hk_ext_z_j_opt <- function(n, p, conf) {
   i <- 1  # i is always 1
 
-  # an approximation of the expected value of the order statistic
-  # for a standard normal distribution. This approximation is
-  # known to be incorrect, especially in the tails of the
-  # distribution. However, it appears to be close enough
-  # for the purposes of determining which value of j is optimum
-  # per Vangel's approach.
+  if (n < 2) {
+    stop("n must be >= 2")
+  }
+
   expected_order_statistic <- function(i, n) {
-    qnorm((i - 0.5) / n)
+    # ref: https://www.gwern.net/docs/statistics/order/1961-harter.pdf
+    int <- function(x) {
+      x * pnorm(-x) ^ (i - 1) * pnorm(x) ^ (n - i) * dnorm(x)
+    }
+    integral <- integrate(int, -Inf, Inf)
+    stopifnot(integral$message == "OK")
+    factorial(n) / (factorial(n - i) * factorial(i - 1)) * integral$value
   }
 
   # Try all the allowable values of j to find the value of T
